/*
** Module   : XCommon
** Abstract : XML related generic common interface.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 EVL 20130214 Created initial version.
*/

package com.goldencode.p2j.xml;

import com.goldencode.p2j.util.*;

/**
 * Interface decribing the common features for XML related objects.
 */
public interface XCommon
extends WrappedResource
{
   // Attributes
   /**
    * Gets the value of the XML schema file for elements with no namespaces.  
    *
    * @return   The value of the nonamespace-schema-location attribute.
    */
   public character getNonamespaceSchemaLocation();
   
   /**
    * Setting the new value for the nonamespace-schema-location attribute.
    * 
    * @param    location
    *           New value of the nonamespace-schema-location attribute to set.
    */
   public void setNonamespaceSchemaLocation(character location);
   
   /**
    * Setting the new value for the nonamespace-schema-location attribute.
    * 
    * @param    location
    *           New value of the nonamespace-schema-location attribute to set.
    */
   public void setNonamespaceSchemaLocation(String location);
   
   // Methods
   /**
    * Adding new match pair for namespace schema and physical file location.
    * 
    * @param    namespace
    *           Target namespace of the schema or am empty string or Unknown value.
    * @param    location
    *           Location of the XML schema file.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical addSchemaLocation(character namespace, character location);

   /**
    * Adding new match pair for namespace schema and physical file location.
    * 
    * @param    namespace
    *           Target namespace of the schema or am empty string or Unknown value.
    * @param    location
    *           Location of the XML schema file.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical addSchemaLocation(String namespace, character location);

   /**
    * Adding new match pair for namespace schema and physical file location.
    * 
    * @param    namespace
    *           Target namespace of the schema or am empty string or Unknown value.
    * @param    location
    *           Location of the XML schema file.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical addSchemaLocation(character namespace, String location);

   /**
    * Adding new match pair for namespace schema and physical file location.
    * 
    * @param    namespace
    *           Target namespace of the schema or am empty string or Unknown value.
    * @param    location
    *           Location of the XML schema file.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical addSchemaLocation(String namespace, String location);
   
   /**
    * Removes the specified attribute.
    * 
    * @param    name
    *           The name of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical removeAttribute(character name);
   
   /**
    * Removes the specified attribute.
    * 
    * @param    name
    *           The name of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical removeAttribute(String name);
   
   /**
    * Removes the specified attribute.
    * 
    * @param    index
    *           The 1-based index of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical removeAttribute(NumberType index);
   
   /**
    * Removes the specified attribute.
    * 
    * @param    index
    *           The 1-based index of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical removeAttribute(double index);

   /**
    * Removes the specified attribute.
    * 
    * @param    name
    *           The name of the attribute to remove.
    * @param    uri
    *           The URI of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical removeAttribute(character name, character uri);
   
   /**
    * Removes the specified attribute.
    * 
    * @param    name
    *           The name of the attribute to remove.
    * @param    uri
    *           The URI of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical removeAttribute(String name, character uri);
   
   /**
    * Removes the specified attribute.
    * 
    * @param    index
    *           The 1-based index of the attribute to remove.
    * @param    uri
    *           The URI of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical removeAttribute(NumberType index, character uri);
   
   /**
    * Removes the specified attribute.
    * 
    * @param    index
    *           The 1-based index of the attribute to remove.
    * @param    uri
    *           The URI of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical removeAttribute(double index, character uri);

   /**
    * Removes the specified attribute.
    * 
    * @param    name
    *           The name of the attribute to remove.
    * @param    uri
    *           The URI of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical removeAttribute(character name, String uri);
   
   /**
    * Removes the specified attribute.
    * 
    * @param    name
    *           The name of the attribute to remove.
    * @param    uri
    *           The URI of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical removeAttribute(String name, String uri);
   
   /**
    * Removes the specified attribute.
    * 
    * @param    index
    *           The 1-based index of the attribute to remove.
    * @param    uri
    *           The URI of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical removeAttribute(NumberType index, String uri);
   
   /**
    * Removes the specified attribute.
    * 
    * @param    index
    *           The 1-based index of the attribute to remove.
    * @param    uri
    *           The URI of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical removeAttribute(double index, String uri);
}
